# -*- coding: utf-8 -*-

"""Top-level package for kakeibox."""

__all__ = ['entry_points', 'plugins', 'responses', 'storage_data_bridge',
           'use_cases']
__author__ = """Jonathan López"""
__email__ = 'jlopez@fipasoft.com.mx'
__version__ = '0.9.1'
